@@ -100,4 +100,18 @@ public interface IPOP3Properties extends IMailProperties {
      */
     public int getPOP3BlockSize();
 
+    /**
+     * Gets supported SSL protocols
+     * @return Supported SSL protocols
+     */
+    public String getSSLProtocols();
+
+    /**
+     * Gets the SSL cipher suites that will be enabled for SSL connections. The property value is a whitespace separated list of tokens
+     * acceptable to the <code>javax.net.ssl.SSLSocket.setEnabledProtocols</code> method.
+     *
+     * @return The SSL cipher suites
+     */
+    public String getSSLCipherSuites();
+
 }
