@@ -53,6 +53,7 @@ import static com.openexchange.pop3.services.POP3ServiceRegistry.getServiceRegis
 import java.nio.charset.Charset;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.mail.api.AbstractProtocolProperties;
 import com.openexchange.mail.api.IMailProperties;
 import com.openexchange.mail.config.MailProperties;
@@ -65,7 +66,7 @@ import com.openexchange.spamhandler.SpamHandler;
  */
 public final class POP3Properties extends AbstractProtocolProperties implements IPOP3Properties {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(POP3Properties.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(POP3Properties.class);
 
     private static final POP3Properties instance = new POP3Properties();
 
@@ -98,6 +99,10 @@ public final class POP3Properties extends AbstractProtocolProperties implements
 
     private String spamHandlerName;
 
+    private String sslProtocols;
+
+    private String cipherSuites;
+
     /**
      * Initializes a new {@link POP3Properties}
      */
@@ -193,10 +198,17 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         spamHandlerName = configuration.getProperty("com.openexchange.pop3.spamHandler", SpamHandler.SPAM_HANDLER_FALLBACK).trim();
         logBuilder.append("\tSpam Handler: ").append(spamHandlerName).append('\n');
 
-        logBuilder.append("Global POP3 properties successfully loaded!");
-        if (LOG.isInfoEnabled()) {
-            LOG.info(logBuilder.toString());
+        sslProtocols = configuration.getProperty("com.openexchange.pop3.ssl.protocols", "SSLv3 TLSv1").trim();
+        logBuilder.append("\tSupported SSL protocols: ").append(sslProtocols).append("\n");
+
+        {
+            final String tmp = configuration.getProperty("com.openexchange.pop3.ssl.ciphersuites", "").trim();
+            this.cipherSuites = Strings.isEmpty(tmp) ? null : tmp;
+            logBuilder.append("\tSupported SSL cipher suites: ").append(null == this.cipherSuites ? "<default>" : cipherSuites).append("\n");
         }
+
+        logBuilder.append("Global POP3 properties successfully loaded!");
+        LOG.info(logBuilder.toString());
     }
 
     @Override
@@ -208,6 +220,8 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         pop3AuthEnc = null;
         spamHandlerName = null;
         pop3BlockSize = 100;
+        sslProtocols = "SSLv3 TLSv1";
+        cipherSuites = null;
     }
 
     @Override
@@ -314,4 +328,14 @@ public final class POP3Properties extends AbstractProtocolProperties implements
         return mailProperties.isWatcherShallClose();
     }
 
+    @Override
+    public String getSSLProtocols() {
+        return sslProtocols;
+    }
+
+    @Override
+    public String getSSLCipherSuites() {
+        return cipherSuites;
+    }
+
 }
