@@ -58,6 +58,7 @@ import com.openexchange.java.StringAllocator;
 import com.openexchange.mail.api.IMailFolderStorage;
 import com.openexchange.pop3.POP3Access;
 import com.openexchange.pop3.config.POP3Config;
+import com.openexchange.pop3.storage.AlreadyLockedException;
 import com.openexchange.pop3.storage.POP3Storage;
 import com.openexchange.pop3.storage.POP3StorageProperties;
 import com.openexchange.pop3.storage.POP3StoragePropertyNames;
@@ -71,9 +72,7 @@ import com.openexchange.session.Session;
  */
 public final class POP3SyncMessagesCallable implements Callable<Object> {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(POP3SyncMessagesCallable.class));
-
-    private static final boolean DEBUG = LOG.isDebugEnabled();
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(POP3SyncMessagesCallable.class);
 
     private final POP3Access pop3Access;
 
@@ -113,7 +112,7 @@ public final class POP3SyncMessagesCallable implements Callable<Object> {
         }
         /*-
          * Refresh possible according to configured refresh rate
-         * 
+         *
          * Check refresh rate setting
          */
         final String server;
@@ -147,34 +146,28 @@ public final class POP3SyncMessagesCallable implements Callable<Object> {
              */
             final int min = parseLoginDelaySeconds(capabilities);
             if (min >= 0 && (min * 1000) > refreshRate) {
-                LOG.warn(new StringBuilder(64).append("Refresh rate of ").append(refreshRate / 1000).append(
-                    "sec is lower than minimum allowed seconds between logins (").append(min).append("sec)"));
+                LOG.warn("Refresh rate of {}sec is lower than minimum allowed seconds between logins ({}sec)", refreshRate / 1000, min);
             }
         }
-        if (DEBUG) {
-            LOG.debug("\n\tSynchronizing messages with POP3 account: " + server, new Throwable());
-        }
+        LOG.debug("\n\tSynchronizing messages with POP3 account: {}", server, new Throwable());
         /*
          * Check default folders since INBOX folder must be present prior to appending to it
          */
         folderStorage.checkDefaultFolders();
-        /*
+        /*-
          * Sync messages
-         */
-        final long st = DEBUG ? System.currentTimeMillis() : 0L;
-        /*
+         *
          * Access POP3 account and synchronize
          */
-        pop3Storage.syncMessages(isExpungeOnQuit(), lastAccessed);
-        /*
-         * Update last-accessed time stamp
-         */
-        final long stamp = System.currentTimeMillis();
-        pop3StorageProperties.addProperty(POP3StoragePropertyNames.PROPERTY_LAST_ACCESSED, Long.toString(stamp));
-        if (DEBUG) {
-            final long dur = stamp - st;
-            final Session session = pop3Access.getSession();
-            LOG.debug("\n\tSynchronization successfully performed for POP3 account \"" + server + "\" (user=" + session.getUserId() + ", context=" + session.getContextId() + ")in: " + dur + "msec");
+        try {
+            pop3Storage.syncMessages(isExpungeOnQuit(), lastAccessed);
+            /*
+             * Update last-accessed time stamp
+             */
+            final long stamp = System.currentTimeMillis();
+            pop3StorageProperties.addProperty(POP3StoragePropertyNames.PROPERTY_LAST_ACCESSED, Long.toString(stamp));
+        } catch (final AlreadyLockedException e) {
+            LOG.debug("\n\tPOP3 account {} locked.", server, e);
         }
         return null;
     }
@@ -191,7 +184,7 @@ public final class POP3SyncMessagesCallable implements Callable<Object> {
         try {
             return Long.valueOf(lastAccessedStr);
         } catch (final NumberFormatException e) {
-            LOG.warn(e.getMessage(), e);
+            LOG.warn("", e);
             return null;
         }
     }
@@ -202,20 +195,14 @@ public final class POP3SyncMessagesCallable implements Callable<Object> {
         final String frequencyStr = pop3StorageProperties.getProperty(POP3StoragePropertyNames.PROPERTY_REFRESH_RATE);
         if (null == frequencyStr) {
             // Fallback to 10 minutes
-            LOG.warn(
-                new StringBuilder(128).append("Missing POP3 property \"").append(POP3StoragePropertyNames.PROPERTY_REFRESH_RATE).append(
-                    '"').append(". Using fallback of ").append(FALLBACK_MINUTES).append(" minutes."),
-                new Throwable());
+            // LOG.warn("Missing POP3 property \"{}\". Using fallback of {} minutes.", POP3StoragePropertyNames.PROPERTY_REFRESH_RATE, FALLBACK_MINUTES, new Throwable());
             return FALLBACK_MINUTES * 60L * 1000L;
         }
         int minutes = 0;
         try {
             minutes = Integer.parseInt(frequencyStr);
         } catch (final NumberFormatException e) {
-            LOG.warn(
-                new StringBuilder(128).append("POP3 property \"").append(POP3StoragePropertyNames.PROPERTY_REFRESH_RATE).append(
-                    "\" is not a number: ``").append(frequencyStr).append("''. Using fallback of ").append(FALLBACK_MINUTES).append(
-                    " minutes."),
+            LOG.warn("POP3 property \"{}\" is not a number: ``{}''. Using fallback of {} minutes.", POP3StoragePropertyNames.PROPERTY_REFRESH_RATE, frequencyStr, FALLBACK_MINUTES,
                 e);
             minutes = FALLBACK_MINUTES;
         }
