@@ -54,6 +54,7 @@ import java.util.Dictionary;
 import java.util.Hashtable;
 import org.osgi.framework.BundleActivator;
 import com.openexchange.caching.CacheService;
+import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.context.ContextService;
@@ -77,7 +78,7 @@ import com.openexchange.user.UserService;
  */
 public final class POP3Activator extends HousekeepingActivator {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(POP3Activator.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(POP3Activator.class);
 
     private volatile POP3StorageProviderServiceTrackerCustomizer customizer;
     private volatile MailAccountPOP3StorageProvider builtInProvider;
@@ -92,25 +93,20 @@ public final class POP3Activator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] {
-            ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class, ContextService.class, TimerService.class, ConfigViewFactory.class  };
+            ConfigurationService.class, CacheService.class, UserService.class, MailAccountStorageService.class,
+            ContextService.class, TimerService.class, ConfigViewFactory.class, CapabilityService.class
+        };
     }
 
     @Override
     protected void handleUnavailability(final Class<?> clazz) {
-        /*
-         * Never stop the server even if a needed service is absent
-         */
-        if (LOG.isWarnEnabled()) {
-            LOG.warn("Absent service: " + clazz.getName());
-        }
+        LOG.warn("Absent service: {}", clazz.getName());
         getServiceRegistry().removeService(clazz);
     }
 
     @Override
     protected void handleAvailability(final Class<?> clazz) {
-        if (LOG.isInfoEnabled()) {
-            LOG.info("Re-available service: " + clazz.getName());
-        }
+        LOG.info("Re-available service: {}", clazz.getName());
         getServiceRegistry().addService(clazz, getService(clazz));
     }
 
@@ -131,9 +127,13 @@ public final class POP3Activator extends HousekeepingActivator {
                     }
                 }
             }
-            final Dictionary<String, String> dictionary = new Hashtable<String, String>();
+            final Dictionary<String, String> dictionary = new Hashtable<String, String>(2);
             dictionary.put("protocol", POP3Provider.PROTOCOL_POP3.toString());
             registerService(MailProvider.class, POP3Provider.getInstance(), dictionary);
+            /*
+             * Signal availability for POP3 provider
+             */
+            getService(CapabilityService.class).declareCapability("pop3");
             /*
              * Add built-in mail account POP3 storage provider
              */
@@ -153,7 +153,7 @@ public final class POP3Activator extends HousekeepingActivator {
              */
             registerService(PreferencesItemService.class, new Enabled(getService(ConfigViewFactory.class)), null);
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         }
     }
@@ -170,13 +170,17 @@ public final class POP3Activator extends HousekeepingActivator {
                 customizer.dropAllRegistrations();
                 this.customizer = null;
             }
+            CapabilityService capabilityService = getService(CapabilityService.class);
+            if (null != capabilityService) {
+                capabilityService.undeclareCapability("pop3");
+            }
             cleanUp();
             /*
              * Clear service registry
              */
             getServiceRegistry().clearRegistry();
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         }
     }
