@@ -62,8 +62,8 @@ import com.openexchange.sessiond.SessiondService;
  */
 public class SessiondServiceServiceTrackerCustomizer implements ServiceTrackerCustomizer<SessiondService,SessiondService> {
 
-    private static final org.apache.commons.logging.Log LOG =
-        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SessiondServiceServiceTrackerCustomizer.class));
+    private static final org.slf4j.Logger LOG =
+        org.slf4j.LoggerFactory.getLogger(SessiondServiceServiceTrackerCustomizer.class);
 
     private final BundleContext context;
 
