@@ -51,6 +51,7 @@ package com.openexchange.pop3.storage.mailaccount;
 
 import static com.openexchange.pop3.storage.mailaccount.util.Utility.prependPath2Fullname;
 import static com.openexchange.pop3.storage.mailaccount.util.Utility.stripPathFromFullname;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.Callable;
@@ -96,8 +97,8 @@ import com.openexchange.tools.session.ServerSession;
  */
 public final class MailAccountPOP3FolderStorage implements IMailFolderStorage {
 
-    static final org.apache.commons.logging.Log LOG =
-        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(MailAccountPOP3FolderStorage.class));
+    static final org.slf4j.Logger LOG =
+        org.slf4j.LoggerFactory.getLogger(MailAccountPOP3FolderStorage.class);
 
     private final IMailFolderStorage delegatee;
 
@@ -295,14 +296,14 @@ public final class MailAccountPOP3FolderStorage implements IMailFolderStorage {
                         if (StorageUtility.INDEX_CONFIRMED_HAM == i) {
                             if (spamHandler.isCreateConfirmedHam()) {
                                 setDefaultMailFolder(i, checkDefaultFolder(realFullname, storage.getSeparator()));
-                            } else if (LOG.isDebugEnabled()) {
-                                LOG.debug("Skipping check for " + defaultFolderNames[i] + " due to SpamHandler.isCreateConfirmedHam()=false");
+                            } else {
+                                LOG.debug("Skipping check for {} due to SpamHandler.isCreateConfirmedHam()=false", defaultFolderNames[i]);
                             }
                         } else if (StorageUtility.INDEX_CONFIRMED_SPAM == i) {
                             if (spamHandler.isCreateConfirmedSpam()) {
                                 setDefaultMailFolder(i, checkDefaultFolder(realFullname, storage.getSeparator()));
-                            } else if (LOG.isDebugEnabled()) {
-                                LOG.debug("Skipping check for " + defaultFolderNames[i] + " due to SpamHandler.isCreateConfirmedSpam()=false");
+                            } else {
+                                LOG.debug("Skipping check for {} due to SpamHandler.isCreateConfirmedSpam()=false", defaultFolderNames[i]);
                             }
                         } else {
                             setDefaultMailFolder(i, checkDefaultFolder(realFullname, storage.getSeparator()));
